@@ -51,6 +51,9 @@ class UserManager(BaseUserManager):
         user.save()
         return user
 
+    def super_users(self):
+        return self.active().filter(is_superuser=True)
+
     def admins(self):
         return self.active().filter(groups__id__in=[1])
 
